@@ -441,7 +441,7 @@ def RUN_ALL_FS(X, y, X_names, labels=None, N=30, output=None, multitask=False):
     FS_OUTPUT = {}
     FS_IDX = {}
 
-    for key,_ in FS_DICT.items():
+    for key, f in FS_DICT.items():
 
         if multitask and 'multi-task' in key:
             pass
@@ -461,7 +461,7 @@ def RUN_ALL_FS(X, y, X_names, labels=None, N=30, output=None, multitask=False):
         if key in FS_DESC_DICT:
             IPython.display.display(IPython.display.HTML('<p>' + FS_DESC_DICT[key] + '</p><br/>'))
 
-        f = FS_DICT[key]
+        # f = FS_DICT[key]
         X_s, idx, _ = f(X, y, X_names, N=N, display=True)
 
         if X_s is not None and X_s.shape[0] > 0 and X_s.shape[1] > 0:
